package com.ruoyi.tuya.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tuya.mapper.BusSupplierReleasePlayMapper;
import com.ruoyi.tuya.domain.BusSupplierReleasePlay;
import com.ruoyi.tuya.service.IBusSupplierReleasePlayService;

/**
 * 平台报价单项目Service业务层处理
 * 
 * @author zf
 * @date 2022-07-22
 */
@Service
public class BusSupplierReleasePlayServiceImpl implements IBusSupplierReleasePlayService 
{
    @Autowired
    private BusSupplierReleasePlayMapper busSupplierReleasePlayMapper;

    /**
     * 查询平台报价单项目
     * 
     * @param id 平台报价单项目主键
     * @return 平台报价单项目
     */
    @Override
    public BusSupplierReleasePlay selectBusSupplierReleasePlayById(Long id)
    {
        return busSupplierReleasePlayMapper.selectBusSupplierReleasePlayById(id);
    }

    /**
     * 查询平台报价单项目列表
     * 
     * @param busSupplierReleasePlay 平台报价单项目
     * @return 平台报价单项目
     */
    @Override
    public List<BusSupplierReleasePlay> selectBusSupplierReleasePlayList(BusSupplierReleasePlay busSupplierReleasePlay)
    {
        return busSupplierReleasePlayMapper.selectBusSupplierReleasePlayList(busSupplierReleasePlay);
    }

    /**
     * 新增平台报价单项目
     * 
     * @param busSupplierReleasePlay 平台报价单项目
     * @return 结果
     */
    @Override
    public int insertBusSupplierReleasePlay(BusSupplierReleasePlay busSupplierReleasePlay)
    {
        return busSupplierReleasePlayMapper.insertBusSupplierReleasePlay(busSupplierReleasePlay);
    }

    /**
     * 修改平台报价单项目
     * 
     * @param busSupplierReleasePlay 平台报价单项目
     * @return 结果
     */
    @Override
    public int updateBusSupplierReleasePlay(BusSupplierReleasePlay busSupplierReleasePlay)
    {
        return busSupplierReleasePlayMapper.updateBusSupplierReleasePlay(busSupplierReleasePlay);
    }

    /**
     * 批量删除平台报价单项目
     * 
     * @param ids 需要删除的平台报价单项目主键
     * @return 结果
     */
    @Override
    public int deleteBusSupplierReleasePlayByIds(Long[] ids)
    {
        return busSupplierReleasePlayMapper.deleteBusSupplierReleasePlayByIds(ids);
    }

    /**
     * 删除平台报价单项目信息
     * 
     * @param id 平台报价单项目主键
     * @return 结果
     */
    @Override
    public int deleteBusSupplierReleasePlayById(Long id)
    {
        return busSupplierReleasePlayMapper.deleteBusSupplierReleasePlayById(id);
    }
}
