package com.ruoyi.tuya.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tuya.domain.BusSupplierReleasePlay;
import com.ruoyi.tuya.service.IBusSupplierReleasePlayService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 平台报价单项目Controller
 *
 * @author zf
 * @date 2022-07-22
 */
@RestController
@RequestMapping("/tuya/supplierPlay")
public class BusSupplierReleasePlayController extends BaseController
{
    @Autowired
    private IBusSupplierReleasePlayService busSupplierReleasePlayService;

    /**
     * 查询平台报价单项目列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:play:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusSupplierReleasePlay busSupplierReleasePlay)
    {
        startPage();
        List<BusSupplierReleasePlay> list = busSupplierReleasePlayService.selectBusSupplierReleasePlayList(busSupplierReleasePlay);
        return getDataTable(list);
    }

    /**
     * 导出平台报价单项目列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:play:export')")
    @Log(title = "平台报价单项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusSupplierReleasePlay busSupplierReleasePlay)
    {
        List<BusSupplierReleasePlay> list = busSupplierReleasePlayService.selectBusSupplierReleasePlayList(busSupplierReleasePlay);
        ExcelUtil<BusSupplierReleasePlay> util = new ExcelUtil<BusSupplierReleasePlay>(BusSupplierReleasePlay.class);
        util.exportExcel(response, list, "平台报价单项目数据");
    }

    /**
     * 获取平台报价单项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('tuya:play:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(busSupplierReleasePlayService.selectBusSupplierReleasePlayById(id));
    }

    /**
     * 新增平台报价单项目
     */
    @PreAuthorize("@ss.hasPermi('tuya:play:add')")
    @Log(title = "平台报价单项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusSupplierReleasePlay busSupplierReleasePlay)
    {
        return toAjax(busSupplierReleasePlayService.insertBusSupplierReleasePlay(busSupplierReleasePlay));
    }

    /**
     * 修改平台报价单项目
     */
    @PreAuthorize("@ss.hasPermi('tuya:play:edit')")
    @Log(title = "平台报价单项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusSupplierReleasePlay busSupplierReleasePlay)
    {
        return toAjax(busSupplierReleasePlayService.updateBusSupplierReleasePlay(busSupplierReleasePlay));
    }

    /**
     * 删除平台报价单项目
     */
    @PreAuthorize("@ss.hasPermi('tuya:play:remove')")
    @Log(title = "平台报价单项目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(busSupplierReleasePlayService.deleteBusSupplierReleasePlayByIds(ids));
    }
}
